@@ -167,7 +167,7 @@ keybind (switch_panels_backward,   handle_switch,        META_TAB_LIST_DOCKS,
           "using a popup window"))
 
 keybind (cycle_group,               handle_cycle,         META_TAB_LIST_GROUP,
-        BINDING_REVERSES,        "<Alt>F6",
+        BINDING_REVERSES,        "<Alt>grave",
         _("Move between windows of an application immediately"))
 keybind (cycle_group_backward,     handle_cycle,         META_TAB_LIST_GROUP,
         REVERSES_AND_REVERSED,   NULL,
@@ -195,8 +195,6 @@ keybind (panel_main_menu, handle_panel,
 keybind (panel_run_dialog, handle_panel,
        META_KEYBINDING_ACTION_PANEL_RUN_DIALOG, 0, "<Alt>F2",
       _("Show the panel's \"Run Application\" dialog box"))
-keybind (toggle_recording, handle_toggle_recording, 0, 0, "<Control><Shift><Alt>r",
-         _("Start or stop recording the session"))
 
 /* Yes, the param is offset by one.  Historical reasons.  (Maybe worth fixing
  * at some point.)  The description is NULL here because the stanza is
