@@ -22,7 +22,6 @@
  * 02111-1307, USA.
  */
 
-#include <config.h>
 #include "prefs.h"
 #include "ui.h"
 #include "frames.h"
@@ -649,7 +648,7 @@ meta_ui_window_should_not_cause_focus (Display *xdisplay,
   /* we shouldn't cause focus if we're an override redirect
    * toplevel which is not foreign
    */
-  if (window && gdk_window_get_type (window) == GDK_WINDOW_TEMP)
+  if (window && gdk_window_get_window_type (window) == GDK_WINDOW_TEMP)
     return TRUE;
   else
     return FALSE;
@@ -675,8 +674,8 @@ meta_text_property_to_utf8 (Display             *xdisplay,
     retval = NULL;
   else
     {
-  retval = list[0];
-  list[0] = g_strdup (""); /* something to free */
+      retval = list[0];
+      list[0] = g_strdup (""); /* something to free */
     }
   
   g_strfreev (list);
